```
          ###      ######## ########### #########   ########    
       ### ###   ###    ###    ###     ###    ### ###    ###    
     ###   ###  ###           ###     ###    ### ###    ###     
   ########### ##########    ###     #########  ###    ###      
  ###     ###        ###    ###     ###    ### ###    ###       
 ###     ### ###    ###    ###     ###    ### ###    ###        
###     ###  ########     ###     ###    ###  ########          
      #########  #########  ########### ########## ###########  
     ###    ### ###    ###     ###     ###            ###       
    ###    ### ###    ###     ###     ###            ###        
   ###    ### #########      ###     ########       ###         
  ###    ### ###    ###     ###     ###            ###          
 ###    ### ###    ###     ###     ###            ###           
#########  ###    ### ########### ###            ###           
```

`astrodrift` is a python library that provides numerical integrator for arbitrary potentials specialising in galatic dynamics simulations. The library provides both cpu compiled and gpu accelerated integration methods utilising a rust-based backend. The library focuses on large quantities of non-interacting test particle integrations particularly useful for tidal stream dynamics. The library also provides interpolation of moving potential increased performance.

# INSTALLATION

```python -m pip install astrodrift```

```uv add astrodrift```

# DEPENDENCIES


# CONTRIBUTION


# CONTRIBUTORS

Jack Patterson
Angus Forrest
John Forbes
